@@ -21,6 +21,7 @@ from gitlabform.input import GroupsAndProjectsProvider
 from gitlabform.output import EffectiveConfiguration
 from gitlabform.processors.group import GroupProcessors
 from gitlabform.processors.project import ProjectProcessors
+from gitlabform.transform import AccessLevelsTransformer
 from gitlabform.ui import (
     info_group_count,
     info_project_count,
@@ -38,12 +39,12 @@ class Formatter(
 
 
 class GitLabForm(object):
-    def __init__(self, project_or_group=None, config_string=None):
+    def __init__(self, include_archived_projects=True, target=None, config_string=None):
 
-        if project_or_group and config_string:
+        if target and config_string:
             # this mode is basically only for testing
 
-            self.project_or_group = project_or_group
+            self.target = target
             self.config_string = config_string
             self.verbose = True
             self.debug = True
@@ -53,7 +54,7 @@ class GitLabForm(object):
             self.noop = False
             self.output_file = None
             self.skip_version_check = True
-            self.include_archived_projects = True  # for unarchive tests
+            self.include_archived_projects = include_archived_projects
             self.just_show_version = False
             self.terminate_after_error = True
             self.only_sections = "all"
@@ -63,7 +64,7 @@ class GitLabForm(object):
             # normal mode
 
             (
-                self.project_or_group,
+                self.target,
                 self.config,
                 self.verbose,
                 self.debug,
@@ -85,12 +86,14 @@ class GitLabForm(object):
             if self.just_show_version:
                 sys.exit(0)
 
-            if not self.project_or_group:
+            if not self.target:
                 fatal(
-                    "project_or_group parameter is required.",
+                    "target parameter is required.",
                     exit_code=EXIT_INVALID_INPUT,
                 )
 
+        self.access_levels_transformer = AccessLevelsTransformer
+
         self.gitlab, self.configuration = self.initialize_configuration_and_gitlab()
 
         self.group_processors = GroupProcessors(
@@ -100,7 +103,9 @@ class GitLabForm(object):
             self.gitlab, self.configuration, self.strict
         )
         self.groups_and_projects_provider = GroupsAndProjectsProvider(
-            self.gitlab, self.configuration, self.include_archived_projects
+            self.gitlab,
+            self.configuration,
+            self.include_archived_projects,
         )
 
         self.non_empty_configs_provider = NonEmptyConfigsProvider(
@@ -124,7 +129,7 @@ class GitLabForm(object):
         )
 
         parser.add_argument(
-            "project_or_group",
+            "target",
             nargs="?",
             help='Project name in "group/project" format \n'
             "OR a single group name \n"
@@ -245,7 +250,7 @@ class GitLabForm(object):
             args.only_sections = args.only_sections.split(",")
 
         return (
-            args.project_or_group,
+            args.target,
             args.config,
             args.verbose,
             args.debug,
@@ -298,6 +303,7 @@ class GitLabForm(object):
             else:
                 gitlab = GitLab(config_path=self.config)
             configuration = gitlab.get_configuration()
+            self.access_levels_transformer.transform(configuration)
             return gitlab, configuration
         except ConfigFileNotFoundException as e:
             fatal(
@@ -317,8 +323,8 @@ class GitLabForm(object):
 
     def run(self):
 
-        projects_with_non_empty_configs, groups_with_non_empty_configs = show_header(
-            self.project_or_group,
+        projects, groups = show_header(
+            self.target,
             self.groups_and_projects_provider,
             self.non_empty_configs_provider,
         )
@@ -329,7 +335,7 @@ class GitLabForm(object):
 
         effective_configuration = EffectiveConfiguration(self.output_file)
 
-        for group in groups_with_non_empty_configs:
+        for group in groups:
 
             group_number += 1
 
@@ -337,7 +343,7 @@ class GitLabForm(object):
                 info_group_count(
                     "@",
                     group_number,
-                    len(groups_with_non_empty_configs),
+                    len(groups),
                     cli_ui.yellow,
                     f"Skipping group {group} as requested to start from {self.start_from_group}...",
                     cli_ui.reset,
@@ -351,7 +357,7 @@ class GitLabForm(object):
             info_group_count(
                 "@",
                 group_number,
-                len(groups_with_non_empty_configs),
+                len(groups),
                 f"Processing group: {group}",
             )
 
@@ -383,14 +389,14 @@ class GitLabForm(object):
                     warning(message)
             finally:
                 debug(
-                    f"@ ({group_number}/{len(groups_with_non_empty_configs)}) FINISHED Processing group: {group}"
+                    f"@ ({group_number}/{len(groups)}) FINISHED Processing group: {group}"
                 )
 
         project_number = 0
         successful_projects = 0
         failed_projects = {}
 
-        for project_and_group in projects_with_non_empty_configs:
+        for project_and_group in projects:
 
             project_number += 1
 
@@ -398,7 +404,7 @@ class GitLabForm(object):
                 info_project_count(
                     "*",
                     project_number,
-                    len(projects_with_non_empty_configs),
+                    len(projects),
                     cli_ui.yellow,
                     f"Skipping project {project_and_group} as requested to start from {self.start_from}...",
                     cli_ui.reset,
@@ -414,7 +420,7 @@ class GitLabForm(object):
             info_project_count(
                 "*",
                 project_number,
-                len(projects_with_non_empty_configs),
+                len(projects),
                 f"Processing project: {project_and_group}",
             )
 
@@ -448,15 +454,15 @@ class GitLabForm(object):
             finally:
 
                 debug(
-                    f"* ({project_number}/{len(projects_with_non_empty_configs)})"
+                    f"* ({project_number}/{len(projects)})"
                     f" FINISHED Processing project: {project_and_group}",
                 )
 
         effective_configuration.write_to_file()
 
         show_summary(
-            groups_with_non_empty_configs,
-            projects_with_non_empty_configs,
+            groups,
+            projects,
             successful_groups,
             successful_projects,
             failed_groups,
