@@ -12,7 +12,7 @@ gl = get_gitlab()
 
 
 @pytest.fixture(scope="function")
-def branches(request, gitlab, group, project):
+def branches(request, gitlab, group_and_project):
     branches = [
         "protect_branch_but_allow_all",
         "protect_branch_with_code_owner_approval_required",
@@ -27,14 +27,14 @@ def branches(request, gitlab, group, project):
         "protect_branch",
     ]
     for branch in branches:
-        gitlab.create_branch(f"{group}/{project}", branch, "main")
+        gitlab.create_branch(group_and_project, branch, "main")
 
     def fin():
         for branch in branches:
-            gitlab.delete_branch(f"{group}/{project}", branch)
+            gitlab.delete_branch(group_and_project, branch)
 
         gitlab.set_file(
-            f"{group}/{project}",
+            group_and_project,
             "main",
             "README.md",
             DEFAULT_README,
@@ -45,8 +45,7 @@ def branches(request, gitlab, group, project):
 
 
 @pytest.fixture(scope="function")
-def one_maintainer_and_two_developers(gitlab, group, project, users):
-    group_and_project = f"{group}/{project}"
+def one_maintainer_and_two_developers(gitlab, group_and_project, users):
 
     gitlab.add_member_to_project(
         group_and_project, users[0], AccessLevel.MAINTAINER.value
@@ -67,22 +66,19 @@ def one_maintainer_and_two_developers(gitlab, group, project, users):
 
 
 class TestBranches:
-    def test__protect_branch_but_allow_all(self, gitlab, group, project, branches):
-        group_and_project_name = f"{group}/{project}"
+    def test__protect_branch_but_allow_all(self, gitlab, group_and_project, branches):
 
         protect_branch_but_allow_all = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_but_allow_all:
                 protected: true
                 developers_can_push: true
                 developers_can_merge: true
         """
-        run_gitlabform(protect_branch_but_allow_all, group_and_project_name)
-        branch = gitlab.get_branch(
-            group_and_project_name, "protect_branch_but_allow_all"
-        )
+        run_gitlabform(protect_branch_but_allow_all, group_and_project)
+        branch = gitlab.get_branch(group_and_project, "protect_branch_but_allow_all")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is True
@@ -90,17 +86,17 @@ class TestBranches:
     # @pytest.mark.skipif(
     #     gl.has_no_license(), reason="this test requires a GitLab license (Paid/Trial)"
     # )
-    # def test__code_owners_approval(self, gitlab, group, project, branches):
-    #     group_and_project_name = f"{group}/{project}"
+    # def test__code_owners_approval(self, gitlab, group_and_project, branches):
+    #     group_and_project = group_and_project
     #
     #     branch_access_levels = gitlab.get_branch_access_levels(
-    #         group_and_project_name, "protect_branch_but_allow_all"
+    #         group_and_project, "protect_branch_but_allow_all"
     #     )
     #     assert branch_access_levels["code_owner_approval_required"] is False
     #
     #     protect_branch_with_code_owner_approval_required = f"""
     #     projects_and_groups:
-    #       {group_and_project_name}:
+    #       {group_and_project}:
     #         branches:
     #           protect_branch_with_code_owner_approval_required:
     #             protected: true
@@ -110,40 +106,38 @@ class TestBranches:
     #     """
     #
     #     run_gitlabform(
-    #         protect_branch_with_code_owner_approval_required, group_and_project_name
+    #         protect_branch_with_code_owner_approval_required, group_and_project
     #     )
     #
     #     branch_access_levels = gitlab.get_branch_access_levels(
-    #         group_and_project_name, "protect_branch_with_code_owner_approval_required"
+    #         group_and_project, "protect_branch_with_code_owner_approval_required"
     #     )
     #     assert branch_access_levels["code_owner_approval_required"] is True
 
-    def test__protect_branch_and_disallow_all(self, gitlab, group, project, branches):
-        group_and_project_name = f"{group}/{project}"
+    def test__protect_branch_and_disallow_all(
+        self, gitlab, group_and_project, branches
+    ):
 
         protect_branch_and_disallow_all = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_disallow_all:
                 protected: true
                 developers_can_push: false
                 developers_can_merge: false
         """
-        run_gitlabform(protect_branch_and_disallow_all, group_and_project_name)
-        branch = gitlab.get_branch(
-            group_and_project_name, "protect_branch_and_disallow_all"
-        )
+        run_gitlabform(protect_branch_and_disallow_all, group_and_project)
+        branch = gitlab.get_branch(group_and_project, "protect_branch_and_disallow_all")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is False
         assert branch["developers_can_merge"] is False
 
-    def test__mixed_config(self, gitlab, group, project, branches):
-        group_and_project_name = f"{group}/{project}"
+    def test__mixed_config(self, gitlab, group_and_project, branches):
 
         mixed_config = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_merges:
                 protected: true
@@ -154,47 +148,46 @@ class TestBranches:
                 developers_can_push: true
                 developers_can_merge: false
         """
-        run_gitlabform(mixed_config, group_and_project_name)
-        branch = gitlab.get_branch(
-            group_and_project_name, "protect_branch_and_allow_merges"
-        )
+        run_gitlabform(mixed_config, group_and_project)
+        branch = gitlab.get_branch(group_and_project, "protect_branch_and_allow_merges")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is False
         assert branch["developers_can_merge"] is True
 
-        branch = gitlab.get_branch(
-            group_and_project_name, "protect_branch_and_allow_pushes"
-        )
+        branch = gitlab.get_branch(group_and_project, "protect_branch_and_allow_pushes")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is False
 
         unprotect_branches = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_merges:
                 protected: false
               protect_branch_and_allow_pushes:
                 protected: false
         """
-        run_gitlabform(unprotect_branches, group_and_project_name)
+        run_gitlabform(unprotect_branches, group_and_project)
 
         for branch in [
             "protect_branch_and_allow_merges",
             "protect_branch_and_allow_pushes",
         ]:
-            branch = gitlab.get_branch(group_and_project_name, branch)
+            branch = gitlab.get_branch(group_and_project, branch)
             assert branch["protected"] is False
 
     def test__mixed_config_with_new_api(
-        self, gitlab, group, project, branches, users, one_maintainer_and_two_developers
+        self,
+        gitlab,
+        group_and_project,
+        branches,
+        users,
+        one_maintainer_and_two_developers,
     ):
-        group_and_project_name = f"{group}/{project}"
-
         mixed_config_with_access_levels = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_merges_access_levels:
                 protected: true
@@ -208,7 +201,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(mixed_config_with_access_levels, group_and_project_name)
+        run_gitlabform(mixed_config_with_access_levels, group_and_project)
 
         (
             push_access_levels,
@@ -217,7 +210,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch_and_allow_merges_access_levels"
+            group_and_project, "protect_branch_and_allow_merges_access_levels"
         )
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
         assert merge_access_levels == [AccessLevel.DEVELOPER.value]
@@ -232,7 +225,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "*_allow_pushes_access_levels"
+            group_and_project, "*_allow_pushes_access_levels"
         )
         assert push_access_levels == [AccessLevel.DEVELOPER.value]
         assert merge_access_levels == [AccessLevel.DEVELOPER.value]
@@ -242,7 +235,7 @@ class TestBranches:
 
         mixed_config_with_access_levels_update = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_merges_access_levels:
                 protected: true
@@ -256,7 +249,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(mixed_config_with_access_levels_update, group_and_project_name)
+        run_gitlabform(mixed_config_with_access_levels_update, group_and_project)
 
         (
             push_access_levels,
@@ -265,7 +258,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch_and_allow_merges_access_levels"
+            group_and_project, "protect_branch_and_allow_merges_access_levels"
         )
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
         assert merge_access_levels == [AccessLevel.MAINTAINER.value]
@@ -280,7 +273,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "*_allow_pushes_access_levels"
+            group_and_project, "*_allow_pushes_access_levels"
         )
         assert push_access_levels == [AccessLevel.MAINTAINER.value]
         assert merge_access_levels == [AccessLevel.MAINTAINER.value]
@@ -290,7 +283,7 @@ class TestBranches:
 
         mixed_config_with_access_levels_unprotect_branches = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_merges_access_levels:
                 protected: false
@@ -299,23 +292,27 @@ class TestBranches:
         """
 
         run_gitlabform(
-            mixed_config_with_access_levels_unprotect_branches, group_and_project_name
+            mixed_config_with_access_levels_unprotect_branches, group_and_project
         )
 
         for branch in [
             "protect_branch_and_allow_merges_access_levels",
             "protect_branch_and_allow_pushes_access_levels",
         ]:
-            branch = gitlab.get_branch(group_and_project_name, branch)
+            branch = gitlab.get_branch(group_and_project, branch)
             assert branch["protected"] is False
 
     @pytest.mark.skipif(
         gl.has_no_license(), reason="this test requires a GitLab license (Paid/Trial)"
     )
     def test__allow_user_ids(
-        self, gitlab, group, project, branches, users, one_maintainer_and_two_developers
+        self,
+        gitlab,
+        group_and_project,
+        branches,
+        users,
+        one_maintainer_and_two_developers,
     ):
-        group_and_project_name = f"{group}/{project}"
 
         user_allowed_to_push_id = gitlab.get_user_to_protect_branch(users[0])
         user_allowed_to_merge_id = gitlab.get_user_to_protect_branch(users[1])
@@ -326,7 +323,7 @@ class TestBranches:
         # testing allowed_to_push  and allowed_to_merge for user support on protect branch (gitlab premium feature)
         mixed_config_with_allowed_to_push_and_merge = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allowed_to_merge:
                 protected: true
@@ -348,9 +345,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.DEVELOPER.value}
         """
 
-        run_gitlabform(
-            mixed_config_with_allowed_to_push_and_merge, group_and_project_name
-        )
+        run_gitlabform(mixed_config_with_allowed_to_push_and_merge, group_and_project)
 
         (
             push_access_levels,
@@ -359,7 +354,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch_and_allowed_to_merge"
+            group_and_project, "protect_branch_and_allowed_to_merge"
         )
 
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
@@ -385,7 +380,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "*_and_allowed_to_push"
+            group_and_project, "*_and_allowed_to_push"
         )
 
         assert push_access_levels == [AccessLevel.DEVELOPER.value]
@@ -406,7 +401,7 @@ class TestBranches:
 
         mixed_config_with_allowed_to_push_and_merge_update = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allowed_to_merge:
                 protected: true
@@ -429,7 +424,7 @@ class TestBranches:
         """
 
         run_gitlabform(
-            mixed_config_with_allowed_to_push_and_merge_update, group_and_project_name
+            mixed_config_with_allowed_to_push_and_merge_update, group_and_project
         )
 
         (
@@ -439,7 +434,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch_and_allowed_to_merge"
+            group_and_project, "protect_branch_and_allowed_to_merge"
         )
 
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
@@ -462,7 +457,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "*_and_allowed_to_push"
+            group_and_project, "*_and_allowed_to_push"
         )
 
         assert push_access_levels == [AccessLevel.MAINTAINER.value]
@@ -484,7 +479,7 @@ class TestBranches:
 
         mixed_config_with_allow_access_levels_with_user_ids = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch_and_allow_access_levels_with_user_ids:
                 protected: true
@@ -502,7 +497,7 @@ class TestBranches:
         """
 
         run_gitlabform(
-            mixed_config_with_allow_access_levels_with_user_ids, group_and_project_name
+            mixed_config_with_allow_access_levels_with_user_ids, group_and_project
         )
 
         (
@@ -512,7 +507,7 @@ class TestBranches:
             merge_access_user_ids,
             unprotect_access_level,
         ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name,
+            group_and_project,
             "protect_branch_and_allow_access_levels_with_user_ids",
         )
 
@@ -542,13 +537,12 @@ class TestBranches:
         assert unprotect_access_level is AccessLevel.MAINTAINER.value
 
     def test_protect_branch_with_old_api_next_update_with_new_api_and_unprotect(
-        self, gitlab, group, project, branches
+        self, gitlab, group_and_project, branches
     ):
-        group_and_project_name = f"{group}/{project}"
 
         config_protect_branch_with_old_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -556,16 +550,16 @@ class TestBranches:
                 developers_can_merge: true
         """
 
-        run_gitlabform(config_protect_branch_with_old_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_old_api, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is True
 
         config_protect_branch_with_new_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -574,7 +568,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(config_protect_branch_with_new_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_new_api, group_and_project)
 
         (
             push_access_levels,
@@ -582,9 +576,7 @@ class TestBranches:
             push_access_user_ids,
             merge_access_user_ids,
             unprotect_access_level,
-        ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch"
-        )
+        ) = gitlab.get_only_branch_access_levels(group_and_project, "protect_branch")
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
         assert merge_access_levels == [AccessLevel.MAINTAINER.value]
         assert push_access_user_ids == []
@@ -593,25 +585,24 @@ class TestBranches:
 
         config_protect_branch_unprotect = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: false
         """
 
-        run_gitlabform(config_protect_branch_unprotect, group_and_project_name)
+        run_gitlabform(config_protect_branch_unprotect, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is False
 
     def test_protect_branch_with_new_api_next_update_with_old_api_and_unprotect(
-        self, gitlab, group, project, branches
+        self, gitlab, group_and_project, branches
     ):
-        group_and_project_name = f"{group}/{project}"
 
         config_protect_branch_with_new_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -620,7 +611,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(config_protect_branch_with_new_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_new_api, group_and_project)
 
         (
             push_access_levels,
@@ -628,9 +619,7 @@ class TestBranches:
             push_access_user_ids,
             merge_access_user_ids,
             unprotect_access_level,
-        ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch"
-        )
+        ) = gitlab.get_only_branch_access_levels(group_and_project, "protect_branch")
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
         assert merge_access_levels == [AccessLevel.MAINTAINER.value]
         assert push_access_user_ids == []
@@ -639,7 +628,7 @@ class TestBranches:
 
         config_protect_branch_with_old_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -647,37 +636,41 @@ class TestBranches:
                 developers_can_merge: true
         """
 
-        run_gitlabform(config_protect_branch_with_old_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_old_api, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is True
 
         config_protect_branch_unprotect = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: false
         """
 
-        run_gitlabform(config_protect_branch_unprotect, group_and_project_name)
+        run_gitlabform(config_protect_branch_unprotect, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is False
 
     @pytest.mark.skipif(
         gl.has_no_license(), reason="this test requires a GitLab license (Paid/Trial)"
     )
     def test_protect_branch_with_old_api_next_update_with_new_api_and_userid_and_unprotect(
-        self, gitlab, group, project, branches, users, one_maintainer_and_two_developers
+        self,
+        gitlab,
+        group_and_project,
+        branches,
+        users,
+        one_maintainer_and_two_developers,
     ):
-        group_and_project_name = f"{group}/{project}"
 
         config_protect_branch_with_old_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -685,9 +678,9 @@ class TestBranches:
                 developers_can_merge: true
         """
 
-        run_gitlabform(config_protect_branch_with_old_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_old_api, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is True
@@ -697,7 +690,7 @@ class TestBranches:
 
         config_protect_branch_with_new_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -713,7 +706,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(config_protect_branch_with_new_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_new_api, group_and_project)
 
         (
             push_access_levels,
@@ -721,9 +714,7 @@ class TestBranches:
             push_access_user_ids,
             merge_access_user_ids,
             unprotect_access_level,
-        ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch"
-        )
+        ) = gitlab.get_only_branch_access_levels(group_and_project, "protect_branch")
 
         assert push_access_levels == [
             AccessLevel.DEVELOPER.value,
@@ -746,25 +737,24 @@ class TestBranches:
 
         config_protect_branch_unprotect = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: false
         """
 
-        run_gitlabform(config_protect_branch_unprotect, group_and_project_name)
+        run_gitlabform(config_protect_branch_unprotect, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is False
 
     def test_unprotect_when_the_rest_of_the_parameters_are_still_specified_old_api(
-        self, gitlab, group, project, branches
+        self, gitlab, group_and_project, branches
     ):
-        group_and_project_name = f"{group}/{project}"
 
         config_protect_branch_with_old_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -772,9 +762,9 @@ class TestBranches:
                 developers_can_merge: true
         """
 
-        run_gitlabform(config_protect_branch_with_old_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_old_api, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is True
         assert branch["developers_can_push"] is True
         assert branch["developers_can_merge"] is True
@@ -784,7 +774,7 @@ class TestBranches:
           api_version: 4
 
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: false
@@ -792,19 +782,18 @@ class TestBranches:
                 developers_can_merge: true
         """
 
-        run_gitlabform(config_unprotect_branch_with_old_api, group_and_project_name)
+        run_gitlabform(config_unprotect_branch_with_old_api, group_and_project)
 
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is False
 
     def test_unprotect_when_the_rest_of_the_parameters_are_still_specified_new_api(
-        self, gitlab, group, project, branches
+        self, gitlab, group_and_project, branches
     ):
-        group_and_project_name = f"{group}/{project}"
 
         config_protect_branch_with_new_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: true
@@ -813,7 +802,7 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(config_protect_branch_with_new_api, group_and_project_name)
+        run_gitlabform(config_protect_branch_with_new_api, group_and_project)
 
         (
             push_access_levels,
@@ -821,9 +810,7 @@ class TestBranches:
             push_access_user_ids,
             merge_access_user_ids,
             unprotect_access_level,
-        ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch"
-        )
+        ) = gitlab.get_only_branch_access_levels(group_and_project, "protect_branch")
         assert push_access_levels == [AccessLevel.NO_ACCESS.value]
         assert merge_access_levels == [AccessLevel.MAINTAINER.value]
         assert push_access_user_ids == []
@@ -832,7 +819,7 @@ class TestBranches:
 
         config_unprotect_branch_with_new_api = f"""
         projects_and_groups:
-          {group_and_project_name}:
+          {group_and_project}:
             branches:
               protect_branch:
                 protected: false
@@ -841,10 +828,10 @@ class TestBranches:
                 unprotect_access_level: {AccessLevel.MAINTAINER.value}
         """
 
-        run_gitlabform(config_unprotect_branch_with_new_api, group_and_project_name)
+        run_gitlabform(config_unprotect_branch_with_new_api, group_and_project)
 
         # old API
-        branch = gitlab.get_branch(group_and_project_name, "protect_branch")
+        branch = gitlab.get_branch(group_and_project, "protect_branch")
         assert branch["protected"] is False
 
         # new API
@@ -854,11 +841,39 @@ class TestBranches:
             push_access_user_ids,
             merge_access_user_ids,
             unprotect_access_level,
-        ) = gitlab.get_only_branch_access_levels(
-            group_and_project_name, "protect_branch"
-        )
+        ) = gitlab.get_only_branch_access_levels(group_and_project, "protect_branch")
         assert push_access_levels is None
         assert merge_access_levels is None
         assert push_access_user_ids is None
         assert merge_access_user_ids is None
         assert unprotect_access_level is None
+
+    def test__config_with_access_level_names(self, gitlab, group_and_project, branches):
+
+        config_with_access_levels_names = f"""
+        projects_and_groups:
+          {group_and_project}:
+            branches:
+              protect_branch_and_allow_merges_access_levels:
+                protected: true
+                push_access_level: no_access        # note "_" or " " and the various
+                merge_access_level: Developer       # case in each line. it should not
+                unprotect_access_level: MAINTAINER  # matter as we allow any case.
+        """
+
+        run_gitlabform(config_with_access_levels_names, group_and_project)
+
+        (
+            push_access_level,
+            merge_access_level,
+            push_access_user_ids,
+            merge_access_user_ids,
+            unprotect_access_level,
+        ) = gitlab.get_only_branch_access_levels(
+            group_and_project, "protect_branch_and_allow_merges_access_levels"
+        )
+        assert push_access_level == [AccessLevel.NO_ACCESS.value]
+        assert merge_access_level == [AccessLevel.DEVELOPER.value]
+        assert push_access_user_ids == []
+        assert merge_access_user_ids == []
+        assert unprotect_access_level is AccessLevel.MAINTAINER.value
